aboutsummaryrefslogtreecommitdiffstats
path: root/mail/mail-ops.c
diff options
context:
space:
mode:
Diffstat (limited to 'mail/mail-ops.c')
-rw-r--r--mail/mail-ops.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/mail/mail-ops.c b/mail/mail-ops.c
index a0bf80ce92..40f3a72309 100644
--- a/mail/mail-ops.c
+++ b/mail/mail-ops.c
@@ -495,8 +495,9 @@ mail_send_message(CamelMimeMessage *message, const char *destination, CamelFilte
camel_medium_add_header (CAMEL_MEDIUM (message), "X-Mailer", version);
camel_mime_message_set_date (message, CAMEL_MESSAGE_DATE_CURRENT, 0);
/* Remove the X-Evolution header so we don't send our flags too ;-) */
camel_medium_remove_header (CAMEL_MEDIUM (message), "X-Evolution");
+ camel_medium_remove_header (CAMEL_MEDIUM (message), "X-Evolution-Source");
/* Get information about the account this was composed by. */
header = camel_medium_get_header (CAMEL_MEDIUM (message), "X-Evolution-Account");
@@ -495,8 +495,9 @@ mail_send_message(CamelMimeMessage *message, const char *destination, CamelFilte
camel_medium_add_header (CAMEL_MEDIUM (message), "X-Mailer", version);
camel_mime_message_set_date (message, CAMEL_MESSAGE_DATE_CURRENT, 0);
- /* Remove the X-Evolution header so we don't send our flags too ;-) */
+ /* Remove the X-Evolution and X-Evolution-Source headers so we don't send our flags & other info too ;-) */
camel_medium_remove_header (CAMEL_MEDIUM (message), "X-Evolution");